==> scribo_0.2.22-862.tar.gz: scribo-0.2.22/src/test/Debug.py <==
#!/usr/bin/env python

"""
===============================================================
    File for debugging all application
===============================================================
"""

__author__ = "Mezhenin Artoym <mezhenin@cs.karelia.ru>"
__version__ = "$Revision: 21 $"
__date__ = "$Date: 2010/02/06 $"
__copyright__ = ""
__license__ = "GPLv2"

import sys

from services.LivejAccount import LivejAccount
from services.BlurtyAccount import BlurtyAccount
from ldm.Message import Message
from ldm.Profile import main_prof
from ldm.SqlDriver import sql_driver

def cback():
    print "Updated..."

def test():
    """
    this is test function
    """
    acc = main_prof.accounts[0]

    msg = acc.posts[0]

    acc.refresh_post(msg)

    return None

def get_uname(acc):
    uname = acc.username


def test2():

    from LivejAccount import LivejAccount
    from Profile import main_prof


    i = 0
    while True:
        i += 1
        p = main_prof.get_posts()
        #get_uname(acc)
        #uname = acc.username
        print i, ' ', len(p)

def test_copy():
    m = Message()
    m.text = 1
    m.title = 2
    m.tags = 3

    mm = m.copy()

    a = LivejAccount()
    a.username = '1'
    a.passwd = '2'

    aa = a.copy()

    p = Profile()
    p.add_account(a)
    p.def_account = a

    pp = p.copy()

    pass

def config_test():

    from ConfigDriver import config

    c = config.get_bool('UI', 'warning_press_refresh')
    cc = config.get_bool('UI', 'autorefresh')
    pass

if __name__ == "__main__":
    test()

    sql_driver.close()

==> scribo_0.3.2-936.tar.gz: scribo-0.3.2/src/test/Debug.py <==
#!/usr/bin/env python

"""
===============================================================
    File for debugging all application
===============================================================
"""

__author__ = "Mezhenin Artoym <mezhenin@cs.karelia.ru>"
__version__ = "$Revision: 21 $"
__date__ = "$Date: 2010/02/06 $"
__copyright__ = ""
__license__ = "GPLv2"

import sys

from services.LivejAccount import LivejAccount
from services.BlurtyAccount import BlurtyAccount
from ldm.Message import Message
from ldm.Profile import main_prof
from ldm.SqlDriver import sql_driver
from BugReporter import BugReporter 

def cback():
    print "Updated..."

def test():
    """
    this is test function
    """
    acc = main_prof.accounts[0]

    msg = acc.posts[0]

    acc.refresh_post(msg)

    return None

def get_uname(acc):
    uname = acc.username


def test2():

    from LivejAccount import LivejAccount
    from Profile import main_prof


    i = 0
    while True:
        i += 1
        p = main_prof.get_posts()
        #get_uname(acc)
        #uname = acc.username
        print i, ' ', len(p)

def test_copy():
    m = Message()
    m.text = 1
    m.title = 2
    m.tags = 3

    mm = m.copy()

    a = LivejAccount()
    a.username = '1'
    a.passwd = '2'

    aa = a.copy()

    p = Profile()
    p.add_account(a)
    p.def_account = a

    pp = p.copy()

    pass

def config_test():

    from ConfigDriver import config

    c = config.get_bool('UI', 'warning_press_refresh')
    cc = config.get_bool('UI', 'autorefresh')
    pass

def bug_test():
    from PyQt4 import QtGui
    app = QtGui.QApplication(sys.argv) # Note: we can't draw dialog box in 
                                         #       BugReporter before gui ini
    try:
        1/0
    except Exception, exc:
        from About import __version__ as ver
        bug = BugReporter(exc, ver, False)

if __name__ == "__main__":
    bug_test()

    sql_driver.close()
